SeekTarget

Enum SeekTarget 

pub enum SeekTarget {
    PacketIndex(usize),
    ClockIndex {
        clock: Symbol,
        index: Ref,
    },
}
Where a seek should begin replaying within a recorded stream.

Examples

use sim_lib_stream_combinators::SeekTarget;

let by_index = SeekTarget::packet_index(2);
assert_eq!(by_index, SeekTarget::PacketIndex(2));

Variants



PacketIndex(usize)

Start at the packet at this zero-based position in the stream.



ClockIndex

Start at the first packet bearing index on the named clock.

Fields

clock: Symbol

The clock whose tick index is matched.

index: Ref

The tick index on clock to seek to.

Implementations

Source

impl SeekTarget

pub fn packet_index(index: usize) -> Self

Builds a SeekTarget::PacketIndex for the given position.

pub fn clock_index(clock: Symbol, index: Ref) -> Self

Builds a SeekTarget::ClockIndex for the given clock and tick index.