pub fn record_bang(source: &Stream) -> Result<StreamRecording>Expand description
Drains source to done and captures it as a StreamRecording.
Errors if the stream is exhausted without reaching its terminal done.
pub fn record_bang(source: &Stream) -> Result<StreamRecording>Drains source to done and captures it as a StreamRecording.
Errors if the stream is exhausted without reaching its terminal done.