pub fn run_bang(
stream: &Stream,
cx: &mut Cx,
run: Ref,
start_seq: u64,
) -> Result<Vec<Event>>Expand description
Drains stream into kernel events for run, starting at start_seq.
Free-function form of Stream::run_events: one
chunk event per packet followed by a done event when the source completes.