pub fn seek(source: Stream, target: SeekTarget) -> StreamExpand description
Returns a stream that skips ahead in source to the first packet at target.
The stream then continues from that packet; if no packet matches, it is empty.
pub fn seek(source: Stream, target: SeekTarget) -> StreamReturns a stream that skips ahead in source to the first packet at target.
The stream then continues from that packet; if no packet matches, it is empty.